@@ -341,6 +341,10 @@ ShapeAlgorithms.getIntersectingShapes = function(doc, entityId, shape, extend) {
     for (var i=0; i<otherEntityIds.length; i++) {
         var otherEntity = doc.queryEntityDirect(otherEntityIds[i]);
 
+        if (isTextBasedEntity(otherEntity)) {
+            continue;
+        }
+
         // ignore intersection points of same entity
         // self intersection points are handled elsewhere
         var same = otherEntityIds[i]===entityId;
@@ -360,7 +364,7 @@ ShapeAlgorithms.getIntersectingShapes = function(doc, entityId, shape, extend) {
             else {
                 // ignore same shape for block reference entities:
                 for (var k=0; k<s.length; k++) {
-                     if (!shape.equals(s[k].data())) {
+                     if (!shape.equals(getPtr(s[k]))) {
                          ret.push(s[k]);
                      }
                 }
@@ -663,7 +667,14 @@ ShapeAlgorithms.autoSplitManual = function(shape, cutDist1, cutDist2, cutPos1, c
         if (!extend) {
             var angleLength1 = rest1.getAngleLength(true);
             var angleLength2 = rest2.getAngleLength(true);
-            if (angleLength1+angleLength2 > shape.getAngleLength()) {
+
+            // rest1 is the same as the segment:
+            var same1 = RMath.fuzzyAngleCompare(rest1.getStartAngle(), segment.getStartAngle()) &&
+                    RMath.fuzzyAngleCompare(rest1.getEndAngle(), segment.getEndAngle()) &&
+                    rest1.isReversed()===segment.isReversed();
+
+            // catch common errors:
+            if (angleLength1+angleLength2 > shape.getAngleLength() || same1) {
                 rest1.trimEndPoint(cutDist2);
                 rest2.trimStartPoint(cutDist1);
 
@@ -1422,7 +1433,7 @@ ShapeAlgorithms.createCircleFrom3Points = function(point1, point2, point3) {
 
     var ret = RCircle.createFrom3Points(point1, point2, point3);
 
-    if (isNull(ret)) {
+    if (!ret.isValid()) {
         ShapeAlgorithms.error = qsTr("No circle possible.");
         return undefined;
     }
@@ -1728,6 +1739,10 @@ ShapeAlgorithms.splineToLineOrArc = function(spline, tolerance, linesOnly) {
  * Converts the given circle into an arc with the given start angle or 0.
  */
 ShapeAlgorithms.circleToArc = function(circle, startAngle) {
+    if (isNull(startAngle)) {
+        startAngle = 0.0;
+    }
+
     return circle.toArc(startAngle);
 };
 
@@ -1810,11 +1825,28 @@ ShapeAlgorithms.ellipseToArcCircleEllipse = function(ellipse) {
  * Transforms the given arc, circle or ellipse into an ellipse
  * using the given function which projects an RVector to another RVector.
  *
- * \returns An REllipse or in special cases an RArc or RCircle.
+ * \returns An REllipse or in special cases an RArc or RCircle. A polyline if no ellipse proxy is available to generate inscribed ellipses.
  *
- * OBSOLETE use RShape::transformArc instead
+ * \todo use RShape::transformArc instead
  */
 ShapeAlgorithms.transformArc = function(arc, fun) {
+    var arcsAsPolylines = (RSettings.getStringValue("IsoProject/GroupArcHandling", "ArcsAsEllipses")==="ArcsAsPolylines");
+
+    if (!REllipse.hasProxy() || arcsAsPolylines) {
+        if (!isEllipseShape(arc)) {
+            var pl = arc.approximateWithLines(arc.getRadius()*2*Math.PI / 64, arc.getStartAngle());
+
+            var plProj = new RPolyline();
+            for (var i=0; i<pl.countVertices(); i++) {
+                var v = pl.getVertexAt(i);
+                fun(v);
+                plProj.appendVertex(v);
+            }
+
+            return plProj;
+        }
+    }
+
     var r1, r2;
 
     if (isEllipseShape(arc)) {
@@ -1826,22 +1858,23 @@ ShapeAlgorithms.transformArc = function(arc, fun) {
         r2 = new RVector(0, arc.getRadius());
     }
 
-    // get vertices at extremities:
+    // get vertices at extremities (quad around full circle, ordered):
     var v1 = arc.getCenter().operator_add(r1).operator_add(r2);
     var v2 = arc.getCenter().operator_add(r1).operator_subtract(r2);
     var v3 = arc.getCenter().operator_subtract(r1).operator_subtract(r2);
     var v4 = arc.getCenter().operator_subtract(r1).operator_add(r2);
 
-    // project those vertices:
+    // project those vertices (project quad):
     fun(v1);
     fun(v2);
     fun(v3);
     fun(v4);
 
-    //var ret = [];
-    // inscribe ellipse into vertices:
     var ellipse = ShapeAlgorithms.createEllipseInscribedFromVertices(v1, v2, v3, v4);
-    //ret.push(ellipse.copy());
+
+    if (isNull(ellipse)) {
+        return arc;
+    }
 
     if (isArcShape(arc) || isEllipseShape(arc)) {
         var sp = arc.getStartPoint();
