@@ -16,7 +16,7 @@ function getIntersectionPoints(e1, e2, limited) {
         limited = true;
     }
 
-    // document is required if entitiy IDs are passed:
+    // document is required if entity IDs are passed:
     var doc = undefined;
     if (isNumber(e1) || isNumber(e2)) {
         doc = getDocument();
@@ -27,16 +27,19 @@ function getIntersectionPoints(e1, e2, limited) {
 
     if (isNumber(e1)) {
         var entity1 = doc.queryEntityDirect(e1);
-        e1 = entity1.data();
+        e1 = getPtr(entity1);
     }
     if (isNumber(e2)) {
         var entity2 = doc.queryEntityDirect(e2);
-        e2 = entity2.data();
+        e2 = getPtr(entity2);
     }
 
     if (isEntity(e1) && isEntity(e2)) {
         return e1.getIntersectionPoints(e2, limited);
     }
+    if (isShape(e1) && isShape(e2)) {
+        return e1.getIntersectionPoints(e2, limited);
+    }
     if (isEntity(e1) && isShape(e2)) {
         return e1.getIntersectionPointsWithShape(e2, limited);
     }
